@@ -1,3 +1,4 @@
+# -*- coding: utf8 -*-
 import logging
 import re
 
@@ -27,6 +28,7 @@ def html_email(email, title=None):
     >>> html_email('username@example.com')
     '<a href="mailto:username@example.com">username@example.com</a>'
     """
+
     if not title:
         title = email
 
@@ -42,11 +44,15 @@ def html_list(data):
 
     for item in data:
 
-        if isinstance(item, dict) and item.get('email'):
-            item = html_email(item.get('email'), item.get('name', None))
+        if isinstance(item, dict):
+            if item.get('email'):
+                item = html_email(item.get('email'), item.get('name', None))
+            elif item.get('name'):
+                item = item.get('name')
 
         if is_email(item):
             item = html_email(item, item)
+
         html += '<li>{}</li>'.format(item)
 
     return html + '</ul>'
